@@ -5,103 +5,115 @@ if fgrep /opt/kde/lib etc/ld.so.conf 1> /dev/null 2> /dev/null ; then
 else
   echo "/opt/kde/lib" >> etc/ld.so.conf
 fi
-( cd opt/kde/include/kdesu ; rm -rf pty.h )
-( cd opt/kde/include/kdesu ; ln -sf kdesu_pty.h pty.h )
-( cd opt/kde/lib ; rm -rf libDCOP.so )
-( cd opt/kde/lib ; ln -sf libDCOP.so.4.0.0 libDCOP.so )
-( cd opt/kde/lib ; rm -rf libDCOP.so.4 )
-( cd opt/kde/lib ; ln -sf libDCOP.so.4.0.0 libDCOP.so.4 )
-( cd opt/kde/lib ; rm -rf libartskde.so )
-( cd opt/kde/lib ; ln -sf libartskde.so.1.0.0 libartskde.so )
-( cd opt/kde/lib ; rm -rf libartskde.so.1 )
-( cd opt/kde/lib ; ln -sf libartskde.so.1.0.0 libartskde.so.1 )
-( cd opt/kde/lib ; rm -rf libkabc.so )
-( cd opt/kde/lib ; ln -sf libkabc.so.1.0.0 libkabc.so )
-( cd opt/kde/lib ; rm -rf libkabc.so.1 )
-( cd opt/kde/lib ; ln -sf libkabc.so.1.0.0 libkabc.so.1 )
-( cd opt/kde/lib ; rm -rf libkatepartinterfaces.so )
-( cd opt/kde/lib ; ln -sf libkatepartinterfaces.so.0.0.0 libkatepartinterfaces.so )
-( cd opt/kde/lib ; rm -rf libkatepartinterfaces.so.0 )
-( cd opt/kde/lib ; ln -sf libkatepartinterfaces.so.0.0.0 libkatepartinterfaces.so.0 )
-( cd opt/kde/lib ; rm -rf libkdecore.so )
-( cd opt/kde/lib ; ln -sf libkdecore.so.4.0.0 libkdecore.so )
-( cd opt/kde/lib ; rm -rf libkdecore.so.4 )
-( cd opt/kde/lib ; ln -sf libkdecore.so.4.0.0 libkdecore.so.4 )
-( cd opt/kde/lib ; rm -rf libkdefakes.so )
-( cd opt/kde/lib ; ln -sf libkdefakes.so.4.0.0 libkdefakes.so )
-( cd opt/kde/lib ; rm -rf libkdefakes.so.4 )
-( cd opt/kde/lib ; ln -sf libkdefakes.so.4.0.0 libkdefakes.so.4 )
-( cd opt/kde/lib ; rm -rf libkdefx.so )
-( cd opt/kde/lib ; ln -sf libkdefx.so.4.0.0 libkdefx.so )
-( cd opt/kde/lib ; rm -rf libkdefx.so.4 )
-( cd opt/kde/lib ; ln -sf libkdefx.so.4.0.0 libkdefx.so.4 )
-( cd opt/kde/lib ; rm -rf libkdeprint.so )
-( cd opt/kde/lib ; ln -sf libkdeprint.so.4.0.0 libkdeprint.so )
 ( cd opt/kde/lib ; rm -rf libkdeprint.so.4 )
-( cd opt/kde/lib ; ln -sf libkdeprint.so.4.0.0 libkdeprint.so.4 )
-( cd opt/kde/lib ; rm -rf libkdeprint_management.so )
-( cd opt/kde/lib ; ln -sf libkdeprint_management.so.4.0.0 libkdeprint_management.so )
-( cd opt/kde/lib ; rm -rf libkdeprint_management.so.4 )
-( cd opt/kde/lib ; ln -sf libkdeprint_management.so.4.0.0 libkdeprint_management.so.4 )
-( cd opt/kde/lib ; rm -rf libkdesasl.so )
-( cd opt/kde/lib ; ln -sf libkdesasl.so.1.0.0 libkdesasl.so )
-( cd opt/kde/lib ; rm -rf libkdesasl.so.1 )
-( cd opt/kde/lib ; ln -sf libkdesasl.so.1.0.0 libkdesasl.so.1 )
-( cd opt/kde/lib ; rm -rf libkdesu.so )
-( cd opt/kde/lib ; ln -sf libkdesu.so.4.0.0 libkdesu.so )
-( cd opt/kde/lib ; rm -rf libkdesu.so.4 )
-( cd opt/kde/lib ; ln -sf libkdesu.so.4.0.0 libkdesu.so.4 )
-( cd opt/kde/lib ; rm -rf libkdeui.so )
-( cd opt/kde/lib ; ln -sf libkdeui.so.4.0.0 libkdeui.so )
-( cd opt/kde/lib ; rm -rf libkdeui.so.4 )
-( cd opt/kde/lib ; ln -sf libkdeui.so.4.0.0 libkdeui.so.4 )
-( cd opt/kde/lib ; rm -rf libkhtml.so )
-( cd opt/kde/lib ; ln -sf libkhtml.so.4.0.0 libkhtml.so )
-( cd opt/kde/lib ; rm -rf libkhtml.so.4 )
-( cd opt/kde/lib ; ln -sf libkhtml.so.4.0.0 libkhtml.so.4 )
-( cd opt/kde/lib ; rm -rf libkio.so )
-( cd opt/kde/lib ; ln -sf libkio.so.4.0.0 libkio.so )
-( cd opt/kde/lib ; rm -rf libkio.so.4 )
-( cd opt/kde/lib ; ln -sf libkio.so.4.0.0 libkio.so.4 )
-( cd opt/kde/lib ; rm -rf libkjava.so )
-( cd opt/kde/lib ; ln -sf libkjava.so.1.0.0 libkjava.so )
-( cd opt/kde/lib ; rm -rf libkjava.so.1 )
-( cd opt/kde/lib ; ln -sf libkjava.so.1.0.0 libkjava.so.1 )
-( cd opt/kde/lib ; rm -rf libkjs.so )
-( cd opt/kde/lib ; ln -sf libkjs.so.1.0.0 libkjs.so )
-( cd opt/kde/lib ; rm -rf libkjs.so.1 )
-( cd opt/kde/lib ; ln -sf libkjs.so.1.0.0 libkjs.so.1 )
-( cd opt/kde/lib ; rm -rf libkmid.so )
-( cd opt/kde/lib ; ln -sf libkmid.so.0.0.95 libkmid.so )
-( cd opt/kde/lib ; rm -rf libkmid.so.0 )
-( cd opt/kde/lib ; ln -sf libkmid.so.0.0.95 libkmid.so.0 )
-( cd opt/kde/lib ; rm -rf libkparts.so )
-( cd opt/kde/lib ; ln -sf libkparts.so.2.0.0 libkparts.so )
-( cd opt/kde/lib ; rm -rf libkparts.so.2 )
-( cd opt/kde/lib ; ln -sf libkparts.so.2.0.0 libkparts.so.2 )
-( cd opt/kde/lib ; rm -rf libkscreensaver.so )
-( cd opt/kde/lib ; ln -sf libkscreensaver.so.4.0.0 libkscreensaver.so )
-( cd opt/kde/lib ; rm -rf libkscreensaver.so.4 )
-( cd opt/kde/lib ; ln -sf libkscreensaver.so.4.0.0 libkscreensaver.so.4 )
-( cd opt/kde/lib ; rm -rf libkscript.so )
-( cd opt/kde/lib ; ln -sf libkscript.so.0.0.0 libkscript.so )
-( cd opt/kde/lib ; rm -rf libkscript.so.0 )
-( cd opt/kde/lib ; ln -sf libkscript.so.0.0.0 libkscript.so.0 )
-( cd opt/kde/lib ; rm -rf libkspell.so )
-( cd opt/kde/lib ; ln -sf libkspell.so.4.0.0 libkspell.so )
-( cd opt/kde/lib ; rm -rf libkspell.so.4 )
-( cd opt/kde/lib ; ln -sf libkspell.so.4.0.0 libkspell.so.4 )
-( cd opt/kde/lib ; rm -rf libktexteditor.so )
-( cd opt/kde/lib ; ln -sf libktexteditor.so.0.0.0 libktexteditor.so )
-( cd opt/kde/lib ; rm -rf libktexteditor.so.0 )
-( cd opt/kde/lib ; ln -sf libktexteditor.so.0.0.0 libktexteditor.so.0 )
-( cd opt/kde/lib ; rm -rf libshellscript.so )
-( cd opt/kde/lib ; ln -sf libshellscript.so.0.0.0 libshellscript.so )
+( cd opt/kde/lib ; ln -sf libkdeprint.so.4.1.0 libkdeprint.so.4 )
 ( cd opt/kde/lib ; rm -rf libshellscript.so.0 )
 ( cd opt/kde/lib ; ln -sf libshellscript.so.0.0.0 libshellscript.so.0 )
-( cd opt/kde/lib ; rm -rf libvcard.so )
-( cd opt/kde/lib ; ln -sf libvcard.so.0.0.0 libvcard.so )
+( cd opt/kde/lib ; rm -rf libkjava.so )
+( cd opt/kde/lib ; ln -sf libkjava.so.1.0.0 libkjava.so )
+( cd opt/kde/lib ; rm -rf libkdesu.so.4 )
+( cd opt/kde/lib ; ln -sf libkdesu.so.4.1.0 libkdesu.so.4 )
+( cd opt/kde/lib ; rm -rf libkio.so )
+( cd opt/kde/lib ; ln -sf libkio.so.4.1.0 libkio.so )
+( cd opt/kde/lib ; rm -rf libkjs.so )
+( cd opt/kde/lib ; ln -sf libkjs.so.1.0.0 libkjs.so )
+( cd opt/kde/lib ; rm -rf libkatepartinterfaces.so.0 )
+( cd opt/kde/lib ; ln -sf libkatepartinterfaces.so.0.0.0 libkatepartinterfaces.so.0 )
+( cd opt/kde/lib ; rm -rf libkparts.so )
+( cd opt/kde/lib ; ln -sf libkparts.so.2.1.0 libkparts.so )
+( cd opt/kde/lib ; rm -rf libkmid.so.0 )
+( cd opt/kde/lib ; ln -sf libkmid.so.0.0.95 libkmid.so.0 )
+( cd opt/kde/lib ; rm -rf libkutils.so.1 )
+( cd opt/kde/lib ; ln -sf libkutils.so.1.1.0 libkutils.so.1 )
+( cd opt/kde/lib ; rm -rf libshellscript.so )
+( cd opt/kde/lib ; ln -sf libshellscript.so.0.0.0 libshellscript.so )
+( cd opt/kde/lib ; rm -rf libkdeprint_management.so )
+( cd opt/kde/lib ; ln -sf libkdeprint_management.so.4.1.0 libkdeprint_management.so )
+( cd opt/kde/lib ; rm -rf libkjs.so.1 )
+( cd opt/kde/lib ; ln -sf libkjs.so.1.0.0 libkjs.so.1 )
+( cd opt/kde/lib ; rm -rf libkdeui.so.4 )
+( cd opt/kde/lib ; ln -sf libkdeui.so.4.1.0 libkdeui.so.4 )
+( cd opt/kde/lib ; rm -rf libkdefx.so )
+( cd opt/kde/lib ; ln -sf libkdefx.so.4.1.0 libkdefx.so )
+( cd opt/kde/lib ; rm -rf libkdefx.so.4 )
+( cd opt/kde/lib ; ln -sf libkdefx.so.4.1.0 libkdefx.so.4 )
+( cd opt/kde/lib ; rm -rf libkdesu.so )
+( cd opt/kde/lib ; ln -sf libkdesu.so.4.1.0 libkdesu.so )
+( cd opt/kde/lib ; rm -rf libkdeui.so )
+( cd opt/kde/lib ; ln -sf libkdeui.so.4.1.0 libkdeui.so )
+( cd opt/kde/lib ; rm -rf libkjava.so.1 )
+( cd opt/kde/lib ; ln -sf libkjava.so.1.0.0 libkjava.so.1 )
+( cd opt/kde/lib ; rm -rf libkscript.so )
+( cd opt/kde/lib ; ln -sf libkscript.so.0.0.0 libkscript.so )
+( cd opt/kde/lib ; rm -rf libkdecore.so.4 )
+( cd opt/kde/lib ; ln -sf libkdecore.so.4.1.0 libkdecore.so.4 )
+( cd opt/kde/lib ; rm -rf libkdeprint.so )
+( cd opt/kde/lib ; ln -sf libkdeprint.so.4.1.0 libkdeprint.so )
+( cd opt/kde/lib ; rm -rf libkdesasl.so.1 )
+( cd opt/kde/lib ; ln -sf libkdesasl.so.1.1.0 libkdesasl.so.1 )
+( cd opt/kde/lib ; rm -rf libkhtml.so.4 )
+( cd opt/kde/lib ; ln -sf libkhtml.so.4.1.0 libkhtml.so.4 )
+( cd opt/kde/lib ; rm -rf libDCOP.so.4 )
+( cd opt/kde/lib ; ln -sf libDCOP.so.4.1.0 libDCOP.so.4 )
+( cd opt/kde/lib ; rm -rf libktexteditor.so )
+( cd opt/kde/lib ; ln -sf libktexteditor.so.0.0.0 libktexteditor.so )
 ( cd opt/kde/lib ; rm -rf libvcard.so.0 )
 ( cd opt/kde/lib ; ln -sf libvcard.so.0.0.0 libvcard.so.0 )
+( cd opt/kde/lib ; rm -rf libkdefakes.so.4 )
+( cd opt/kde/lib ; ln -sf libkdefakes.so.4.1.0 libkdefakes.so.4 )
+( cd opt/kde/lib ; rm -rf libkscreensaver.so )
+( cd opt/kde/lib ; ln -sf libkscreensaver.so.4.1.0 libkscreensaver.so )
+( cd opt/kde/lib ; rm -rf libDCOP.so )
+( cd opt/kde/lib ; ln -sf libDCOP.so.4.1.0 libDCOP.so )
+( cd opt/kde/lib ; rm -rf libartskde.so )
+( cd opt/kde/lib ; ln -sf libartskde.so.1.1.0 libartskde.so )
+( cd opt/kde/lib ; rm -rf libkdeprint_management.so.4 )
+( cd opt/kde/lib ; ln -sf libkdeprint_management.so.4.1.0 libkdeprint_management.so.4 )
+( cd opt/kde/lib ; rm -rf libkatepartinterfaces.so )
+( cd opt/kde/lib ; ln -sf libkatepartinterfaces.so.0.0.0 libkatepartinterfaces.so )
+( cd opt/kde/lib ; rm -rf libkparts.so.2 )
+( cd opt/kde/lib ; ln -sf libkparts.so.2.1.0 libkparts.so.2 )
+( cd opt/kde/lib ; rm -rf libkscript.so.0 )
+( cd opt/kde/lib ; ln -sf libkscript.so.0.0.0 libkscript.so.0 )
+( cd opt/kde/lib ; rm -rf libvcard.so )
+( cd opt/kde/lib ; ln -sf libvcard.so.0.0.0 libvcard.so )
+( cd opt/kde/lib ; rm -rf libkscreensaver.so.4 )
+( cd opt/kde/lib ; ln -sf libkscreensaver.so.4.1.0 libkscreensaver.so.4 )
+( cd opt/kde/lib ; rm -rf libkabc.so )
+( cd opt/kde/lib ; ln -sf libkabc.so.1.1.0 libkabc.so )
+( cd opt/kde/lib ; rm -rf libkdecore.so )
+( cd opt/kde/lib ; ln -sf libkdecore.so.4.1.0 libkdecore.so )
+( cd opt/kde/lib ; rm -rf libkmediaplayer.so )
+( cd opt/kde/lib ; ln -sf libkmediaplayer.so.0.0.0 libkmediaplayer.so )
+( cd opt/kde/lib ; rm -rf libkutils.so )
+( cd opt/kde/lib ; ln -sf libkutils.so.1.1.0 libkutils.so )
+( cd opt/kde/lib ; rm -rf libkdefakes.so )
+( cd opt/kde/lib ; ln -sf libkdefakes.so.4.1.0 libkdefakes.so )
+( cd opt/kde/lib ; rm -rf libkmediaplayer.so.0 )
+( cd opt/kde/lib ; ln -sf libkmediaplayer.so.0.0.0 libkmediaplayer.so.0 )
+( cd opt/kde/lib ; rm -rf libkmid.so )
+( cd opt/kde/lib ; ln -sf libkmid.so.0.0.95 libkmid.so )
+( cd opt/kde/lib ; rm -rf libktexteditor.so.0 )
+( cd opt/kde/lib ; ln -sf libktexteditor.so.0.0.0 libktexteditor.so.0 )
+( cd opt/kde/lib ; rm -rf libkdesasl.so )
+( cd opt/kde/lib ; ln -sf libkdesasl.so.1.1.0 libkdesasl.so )
+( cd opt/kde/lib ; rm -rf libkspell.so.4 )
+( cd opt/kde/lib ; ln -sf libkspell.so.4.1.0 libkspell.so.4 )
+( cd opt/kde/lib ; rm -rf libartskde.so.1 )
+( cd opt/kde/lib ; ln -sf libartskde.so.1.1.0 libartskde.so.1 )
+( cd opt/kde/lib ; rm -rf libkspell.so )
+( cd opt/kde/lib ; ln -sf libkspell.so.4.1.0 libkspell.so )
+( cd opt/kde/lib ; rm -rf libkabc.so.1 )
+( cd opt/kde/lib ; ln -sf libkabc.so.1.1.0 libkabc.so.1 )
+( cd opt/kde/lib ; rm -rf libkhtml.so )
+( cd opt/kde/lib ; ln -sf libkhtml.so.4.1.0 libkhtml.so )
+( cd opt/kde/lib ; rm -rf libkio.so.4 )
+( cd opt/kde/lib ; ln -sf libkio.so.4.1.0 libkio.so.4 )
+( cd opt/kde/share/doc/HTML/en/kdelibs-apidocs ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kdelibs-apidocs ; ln -sf /root/kde-3.1.2/kdelibs/temp/opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kspell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kspell ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kspell ; ln -sf /root/kde-3.1.2/kdelibs/temp/opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/icons ; rm -rf default.kde )
+( cd opt/kde/share/icons ; ln -sf crystalsvg default.kde )
+( cd opt/kde/include/kdesu ; rm -rf pty.h )
+( cd opt/kde/include/kdesu ; ln -sf kdesu_pty.h pty.h )
